#!/bin/bash
#

STATE_OK=0
STATE_WARNING=1
STATE_CRITICAL=2
STATE_UNKNOWN=3
STATE_DEPENDENT=4


function print_version () {
    cat <<EOF
EOF
}

function print_help () {
    print_version
    cat <<EOF

EOF
    print_usage

cat <<EOF

Options:
 -h, --help
    Print detailed help screen

 -V, --version
    Print version information
EOF
}

function print_usage () {
    cat <<EOF
Usage: check_oracle_writeaccess -h, --help
       check_oracle_writeaccess -V, --version     
       check_oracle_writeaccess TNSNAME USER PASSWORD TABLENAME
EOF
}

case "$1" in
        --help|-h)
	    print_help
            exit 0
        ;;
        --version|-V)
	    print_revision
            exit 0
	;;
	-*)
	    print_usage
	    exit $STATE_UNKNOWN
	;;
esac

#if [ $# -ne 4 ] ; then
#    print_usage
#    exit $STATE_UNKNOWN
#fi

TNSNAME="$1"
USER="$2"
PASSWORD="$3"
TABLENAME="$4"
ORACLE_HOME="/oracle/10.1.0/client_1/"
# Try to determine ORAHOME
#if [ -z "$ORACLE_HOME" ]
#then
#    ORACLE_HOME="$(egrep ':(Y|N)$' /etc/oratab | head -n 1 | cut -d: -f2)"
#fi

#if [ -z "$ORACLE_HOMEi" ]
#then
#    echo "ORACLE_HOME not set, also cannot determine that from /etc/oratab." >&2
#    exit $STATE_UNKNOWN
#fi

#export ORACLE_HOME
SQLPLUS="$ORACLE_HOME/bin/sqlplus"
#if [ ! -x "$SQLPLUS" ]
#then
#    echo "Cannot find sqlplus in $SQLPLUS" >&2
#    exit $STATE_UNKNOWN
#fi

#OUTPUT="$(echo -en "INSERT INTO $TABLENAME VALUES(1);\r\nDELETE FROM $TABLENAME;\r\nEXIT\r\n" | "$SQLPLUS" "$USER/$PASSWORD@$TNSNAME" 2>&1 )"
#OUTPUT="$(echo -en "INSERT INTO $TABLENAME VALUES(1);\r\nDELETE FROM $TABLENAME;\r\nEXIT\r\n" | "$SQLPLUS" "$USER/$PASSWORD@$TNSNAME" )"
OUTPUT="$(echo -en "INSERT INTO nagios  VALUES(1);\r\nDELETE FROM nagios;\r\nEXIT\r\n" | "$SQLPLUS" "nagios/nagios@"$TNSNAME"" )"
EXITCODE="$?"

ROWINFO="$(echo "$OUTPUT" | egrep 'row (created|deleted)')"
ERRORINFO="$(echo "$OUTPUT" | egrep '^ORA-[0-9]{3,6}:' | head -n 1)"

if [ "$ROWINFO" = "1 row created.
1 row deleted." ] ; then
    echo "Oracle OK - 1 row created, 1 row deleted"
    exit $STATE_OK
elif [ "$ERRORINFO" ] ; then
    echo "$ERRORINFO"
    exit $STATE_CRITICAL
elif [ "$EXITCODE" -ne 0 ] ; then
    echo "SQL*Plus exited with code $EXITCODE"
    exit $STATE_CRITICAL
else
    echo "Unknown error."
    exit $STATE_CRITICAL
fi
